@@ -6,9 +6,6 @@ use autodie;
 
 use Socket;
 
-# bug in this module: it breaks when loaded dynamically
-use Socket::MsgHdr;
-
 use Data::Dumper;
 
 use FindBin;
@@ -16,9 +13,9 @@ use lib "$FindBin::Bin/../lib";
 
 use Protocol::DBus::Client;
 
-my $dbus = Protocol::DBus::Client::system();
+my $dbus = $> ? Protocol::DBus::Client::login_session() : Protocol::DBus::Client::system();
 
-$dbus->do_authn();
+$dbus->initialize();
 
 $dbus->send_call(
     member => 'AddMatch',
