@@ -41,12 +41,13 @@ implementation.)
 =cut
 
 use Call::Context;
-use Promise::ES6;
 
 use Protocol::DBus::Message;
 use Protocol::DBus::Parser;
 use Protocol::DBus::WriteMsg;
 
+use constant _PROMISE_CLASS => 'Promise::ES6';
+
 #----------------------------------------------------------------------
 
 =head1 METHODS
@@ -96,7 +97,7 @@ sub flush_write_queue {
 
 #----------------------------------------------------------------------
 
-=head2 I<OBJ>->send_call( %OPTS )
+=head2 $promise = I<OBJ>->send_call( %OPTS )
 
 Send a METHOD_CALL message.
 
@@ -116,6 +117,20 @@ your input is invalid or if there’s a socket I/O error.
 
 use constant _METHOD_RETURN_NUM => Protocol::DBus::Message::Header::MESSAGE_TYPE()->{'METHOD_RETURN'};
 
+sub _get_promise_class {
+    my ($self) = @_;
+
+    $self->{'_loaded_promise'} ||= do {
+        local ($!, $@);
+        my $path = $self->_PROMISE_CLASS() . '.pm';
+        $path =~ s[::][/]g;
+
+        require $path;
+    };
+
+    return $self->_PROMISE_CLASS();
+}
+
 sub send_call {
     my ($self, %opts) = @_;
 
@@ -132,7 +147,7 @@ sub send_call {
         # in order to avoid memory leaks.
         my $on_return_hr = $self->{'_on_return'} ||= {};
 
-        return Promise::ES6->new( sub {
+        return $self->_get_promise_class()->new( sub {
             my ($resolve, $reject) = @_;
 
             $on_return_hr->{$serial} = sub {
@@ -147,10 +162,13 @@ sub send_call {
     };
 }
 
-=head2 I<OBJ>->send_return( $ORIG_MSG, %OPTS )
+=head2 $flushed_yn = I<OBJ>->send_return( $ORIG_MSG, %OPTS )
 
 Send a METHOD_RETURN message.
 
+The return is a boolean that indicates whether the message is sent (truthy)
+or remains queued (falsy).
+
 Arguments are similar to C<send_call()> except for the header differences
 that the D-Bus specification describes. Also, C<destination> is not given
 directly but is instead inferred from the $ORIG_MSG. (Behavior is
@@ -167,7 +185,7 @@ sub send_return {
     );
 }
 
-=head2 I<OBJ>->send_error( $ORIG_MSG, %OPTS )
+=head2 $flushed_yn = I<OBJ>->send_error( $ORIG_MSG, %OPTS )
 
 Like C<send_return()>, but sends an error instead. The
 C<error_name> parameter is required.
@@ -198,10 +216,10 @@ sub _response_fields_from_orig_msg {
     );
 }
 
-=head2 I<OBJ>->send_signal( %OPTS )
+=head2 $flushed_yn = I<OBJ>->send_signal( %OPTS )
 
-Like C<send_call()> but sends a signal rather than a method call,
-and a promise is not returned.
+Like C<send_call()> but sends a signal rather than a method call.
+This also returns a boolean like C<send_return()>.
 
 =cut
 
@@ -229,7 +247,7 @@ have little need for this function.
 sub big_endian {
     my ($self) = @_;
 
-    if (@_ > 0) {
+    if (@_ > 1) {
         my $old = $self->{'_big_endian'};
         $self->{'_big_endian'} = !!$_[1];
 
